==> owncloud-app-documents-1%3A0.10.2-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/it.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Documenti",
    "Can't create document" : "Impossibile creare il documento",
    "You don't have permission to rename this document" : "Non hai i permessi per rinominare questo documento",
    "Directory saved successfully." : "Cartella salvata correttamente.",
    "An error occurred while changing directory." : "Si è verificato un errore durante il cambio di cartella.",
    "Saved" : "Salvato",
    "Format filter server is down or misconfigured" : "Il formato del filtro del server è inattivo o configurato in modo errato",
    "Conversion failed. Check log for details." : "Conversione non riuscita. Controlla i log per i dettagli.",
    "document-styles" : "document-styles",
    "document-content" : "document-content",
    "bold" : "grassetto",
    "italic" : "corsivo",
    "solid" : "solido",
    "pt" : "pt",
    "Saving..." : "Salvataggio in corso...",
    "Failed to load documents." : "Caricamento documenti non riuscito.",
    "No documents were found. Upload or create a document to get started!" : "Nessun documento trovato. Carica o crea un documento per iniziare!",
    "No connection to server. Trying to reconnect." : "Nessuna connessione al server. Riprova a connetterti.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Lasciare questa pagina nella modalità potrebbe causare il mancato salvataggio dei dati. Si consiglia invece di utilizzare il pulsante 'Chiudi'.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Caricamento del documento non riuscito. Controlla se può essere aperto con un editor odt esterno. Ciò può anche significare che è stato tolto dalla condivisione o che è stato eliminato recentemente.",
    "Save" : "Salva",
    "Loading documents..." : "Caricamento documenti...",
    "'.' is an invalid file name." : "'.' non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nome non valido, '\\', '/', '<', '>', ':', '\"', '|', '?' e '*' non sono consentiti.",
    "Align Left" : "Allineamento a sinistra",
    "Alignment" : "Allineamento",
    "Align Right" : "Allineamento a destra",
    "Annotate" : "Annota",
    "Background" : "Sfondo",
    "Bold" : "Grassetto",
    "Bottom" : "In basso",
    "Cancel" : "Annulla",
    "Center" : "Centrato",
    "Clone" : "Clona",
    "Clone this Style" : "Clona questo stile",
    "Close" : "Chiudi",
    "Color" : "Colore",
    "Create" : "Crea",
    "Decrease Indent" : "Riduci rientro",
    "Default Style" : "Stile predefinito",
    "Delete" : "Elimina",
    "Family" : "Famiglia",
    "Font" : "Carattere",
    "Font Effects" : "Effetti carattere",
    "Format" : "Formato",
    "Increase Indent" : "Aumenta rientro",
    "Insert Image" : "Inserisci immagine",
    "Invite Members" : "Invita membri",
    "Italic" : "Corsivo",
    "Justified" : "Giustificato",
    "Justify" : "Giustifica",
    "Left" : "Sinistra",
    "Loading" : "Caricamento",
    "Members" : "Membri",
    "New Name:" : "Nuovo nome:",
    "OK" : "OK",
    "Open" : "Apri",
    "Options" : "Opzioni",
    "Paragraph..." : "Paragrafo...",
    "Paragraph Styles" : "Stili paragrafo",
    "Redo" : "Rifai",
    "Right" : "Destra",
    "Size" : "Dimensione",
    "Spacing" : "Spaziatura",
    "Strikethrough" : "Barrato",
    "Style" : "Stile",
    "Text" : "Testo",
    "Top" : "In alto",
    "Underline" : "Sottolineato",
    "Undo" : "Annulla",
    "Unknown Author" : "Autore sconosciuto",
    "Edit" : "Modifica",
    "Share" : "Condividi",
    "guest" : "ospite",
    "MS Word support (requires openOffice/libreOffice)" : "Supporto MS Word (richiede openOffice/libreOffice)",
    "Local" : "Locale",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice è installato su questo server. Il percorso al binario è fornito tramite preview_libreoffice_path in config.php",
    "External" : "Esterno",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice è installato su un server esterno che esegue un servizio di filtro del formato",
    "Disabled" : "Disabilitato",
    "No MS Word support" : "Nessun supporto per MS Word",
    "scheme://domain.tld[:port]" : "scheme://dominio.tld[:porta]",
    "Server URL" : "URL del server",
    "Apply and test" : "Applica e prova",
    "New document" : "Nuovo documento",
    "Upload (max. %s)" : "Caricamento (massimo %s)",
    "Upload" : "Carica",
    "Save new documents to" : "Salva i nuovi documenti in",
    "Wrong password. Please retry." : "Password errata. Riprova.",
    "Password" : "Password",
    "Guest %s" : "Ospite %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Questo collegamento è scaduto o non è mai esistito. Contatta la persona che lo ha condiviso per i dettagli.",
    "Advanced feature-set" : "Funzionalità avanzate",
    "(Unstable)" : "(Non stabile)"
},
"nplurals=2; plural=(n != 1);");

==> owncloud-app-documents-1%3A0.13.1-1-any.pkg.tar.xz: usr/share/webapps/owncloud/apps/documents/l10n/it.js <==
OC.L10N.register(
    "documents",
    {
    "Documents" : "Documenti",
    "Can't create document" : "Impossibile creare il documento",
    "You don't have permission to rename this document" : "Non hai i permessi per rinominare questo documento",
    "File does not exist" : "Il file non esiste",
    "Directory saved successfully." : "Cartella salvata correttamente.",
    "An error occurred while changing directory." : "Si è verificato un errore durante il cambio di cartella.",
    "Saved" : "Salvato",
    "Format filter server is down or misconfigured" : "Il formato del filtro del server è inattivo o configurato in modo errato",
    "Conversion failed. Check log for details." : "Conversione non riuscita. Controlla i log per i dettagli.",
    "Saving..." : "Salvataggio in corso...",
    "Failed to load documents." : "Caricamento documenti non riuscito.",
    "No documents were found. Upload or create a document to get started!" : "Nessun documento trovato. Carica o crea un documento per iniziare!",
    "No connection to server. Trying to reconnect." : "Nessuna connessione al server. Riprova a connetterti.",
    "Leaving this page in Editor mode might cause unsaved data. It is recommended to use 'Close' button instead." : "Lasciare questa pagina nella modalità potrebbe causare il mancato salvataggio dei dati. Si consiglia invece di utilizzare il pulsante 'Chiudi'.",
    "Failed to load this document. Please check if it can be opened with an external odt editor. This might also mean it has been unshared or deleted recently." : "Caricamento del documento non riuscito. Controlla se può essere aperto con un editor odt esterno. Ciò può anche significare che è stato tolto dalla condivisione o che è stato eliminato recentemente.",
    "Save" : "Salva",
    "Loading documents..." : "Caricamento documenti...",
    "'.' is an invalid file name." : "'.' non è un nome file valido.",
    "File name cannot be empty." : "Il nome del file non può essere vuoto.",
    "Invalid name, '\\', '/', '<', '>', ':', '\"', '|', '?' and '*' are not allowed." : "Nome non valido, '\\', '/', '<', '>', ':', '\"', '|', '?' e '*' non sono consentiti.",
    "Align Left" : "Allineamento a sinistra",
    "Alignment" : "Allineamento",
    "Align Right" : "Allineamento a destra",
    "Annotate" : "Annota",
    "Background" : "Sfondo",
    "Bold" : "Grassetto",
    "Bottom" : "In basso",
    "Cancel" : "Annulla",
    "Center" : "Centrato",
    "Clone" : "Clona",
    "Clone this Style" : "Clona questo stile",
    "Close" : "Chiudi",
    "Color" : "Colore",
    "Create" : "Crea",
    "Decrease Indent" : "Riduci rientro",
    "Default Style" : "Stile predefinito",
    "Delete" : "Elimina",
    "Family" : "Famiglia",
    "Font" : "Carattere",
    "Font Effects" : "Effetti carattere",
    "Format" : "Formato",
    "Increase Indent" : "Aumenta rientro",
    "Insert Image" : "Inserisci immagine",
    "Invite Members" : "Invita membri",
    "Italic" : "Corsivo",
    "Justified" : "Giustificato",
    "Justify" : "Giustifica",
    "Left" : "Sinistra",
    "Loading" : "Caricamento",
    "Members" : "Membri",
    "New Name:" : "Nuovo nome:",
    "OK" : "OK",
    "Open" : "Apri",
    "Options" : "Opzioni",
    "Paragraph..." : "Paragrafo...",
    "Paragraph Styles" : "Stili paragrafo",
    "Redo" : "Rifai",
    "Right" : "Destra",
    "Size" : "Dimensione",
    "Spacing" : "Spaziatura",
    "Strikethrough" : "Barrato",
    "Style" : "Stile",
    "Text" : "Testo",
    "Top" : "In alto",
    "Underline" : "Sottolineato",
    "Undo" : "Annulla",
    "Unknown Author" : "Autore sconosciuto",
    "Shared" : "Condiviso",
    "Error" : "Errore",
    "Error while sharing" : "Errore durante la condivisione",
    "Error while unsharing" : "Errore durante la rimozione della condivisione",
    "Error while changing permissions" : "Errore durante la modifica dei permessi",
    "Shared with you and the group {group} by {owner}" : "Condiviso con te e con il gruppo {group} da {owner}",
    "Shared with you by {owner}" : "Condiviso con te da {owner}",
    "Share with users or groups …" : "Condividi con utenti o gruppi...",
    "Share with users, groups or remote users …" : "Condividi con utenti, gruppi o utenti remoti...",
    "Share" : "Condividi",
    "Share with people on other ownClouds using the syntax username@example.com/owncloud" : "Condividi con persone su altri ownCloud utilizzando la sintassi nomeutente@esempio.com/owncloud",
    "Share link" : "Condividi collegamento",
    "The public link will expire no later than {days} days after it is created" : "Il collegamento pubblico scadrà non più tardi di {days} giorni dopo la sua creazione",
    "Link" : "Collegamento",
    "Password protect" : "Proteggi con password",
    "Password" : "Password",
    "Choose a password for the public link" : "Scegli una password per il collegamento pubblico",
    "Allow editing" : "Consenti la modifica",
    "Email link to person" : "Invia collegamento tramite email",
    "Send" : "Invia",
    "Set expiration date" : "Imposta data di scadenza",
    "Expiration" : "Scadenza",
    "Expiration date" : "Data di scadenza",
    "An error occured. Please try again" : "Si è verificato un errore. Prova ancora",
    "Adding user..." : "Aggiunta utente in corso...",
    "group" : "gruppo",
    "remote" : "remota",
    "Resharing is not allowed" : "La ri-condivisione non è consentita",
    "Shared in {item} with {user}" : "Condiviso in {item} con {user}",
    "Unshare" : "Rimuovi condivisione",
    "notify by email" : "notifica tramite email",
    "can share" : "può condividere",
    "can edit" : "può modificare",
    "access control" : "controllo d'accesso",
    "create" : "crea",
    "change" : "cambia",
    "delete" : "elimina",
    "Password protected" : "Protetta da password",
    "Error unsetting expiration date" : "Errore durante la rimozione della data di scadenza",
    "Error setting expiration date" : "Errore durante l'impostazione della data di scadenza",
    "Sending ..." : "Invio in corso...",
    "Email sent" : "Email inviata",
    "Warning" : "Avviso",
    "Edit" : "Modifica",
    "guest" : "ospite",
    "MS Word support (requires openOffice/libreOffice)" : "Supporto MS Word (richiede openOffice/libreOffice)",
    "Local" : "Locale",
    "openOffice/libreOffice is installed on this server. Path to binary is provided via preview_libreoffice_path in config.php" : "openOffice/libreOffice è installato su questo server. Il percorso al binario è fornito tramite preview_libreoffice_path in config.php",
    "External" : "Esterno",
    "openOffice/libreOffice is installed on external server running a format filter server" : "openOffice/libreOffice è installato su un server esterno che esegue un servizio di filtro del formato",
    "Disabled" : "Disabilitato",
    "No MS Word support" : "Nessun supporto per MS Word",
    "scheme://domain.tld[:port]" : "scheme://dominio.tld[:porta]",
    "Server URL" : "URL del server",
    "Apply and test" : "Applica e prova",
    "New document" : "Nuovo documento",
    "Upload (max. %s)" : "Caricamento (massimo %s)",
    "Upload" : "Carica",
    "Save new documents to" : "Salva i nuovi documenti in",
    "Wrong password. Please retry." : "Password errata. Riprova.",
    "Guest %s" : "Ospite %s",
    "This link has been expired or is never existed. Please contact the person who shared it with you for details." : "Questo collegamento è scaduto o non è mai esistito. Contatta la persona che lo ha condiviso per i dettagli.",
    "Advanced feature-set" : "Funzionalità avanzate",
    "(Unstable)" : "(Non stabile)"
},
"nplurals=2; plural=(n != 1);");
